@@ -29,15 +29,17 @@
 #include <KAboutData>
 #include <KLocalizedString>
 
+#include "upnptestwidget.h"
 #include <util/functions.h>
 #include <util/log.h>
-#include "upnptestwidget.h"
 
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    KAboutData about(QStringLiteral("ktupnp"), i18n("KTUPnPTest"),
-                     QStringLiteral("1.0"), i18n("KTorrent's UPnP test application"),
+    KAboutData about(QStringLiteral("ktupnp"),
+                     i18n("KTUPnPTest"),
+                     QStringLiteral("1.0"),
+                     i18n("KTorrent's UPnP test application"),
                      KAboutLicense::GPL,
                      i18n("&copy; 2005 - 2007 Joris Guisson and Ivan Vasic"),
                      QString(),
@@ -61,7 +63,7 @@ int main(int argc, char** argv)
         str += bt::DirSeparator();
 
     bt::InitLog(str + QStringLiteral("ktupnptest.log"));
-    UPnPTestWidget* mwnd = new UPnPTestWidget();
+    UPnPTestWidget *mwnd = new UPnPTestWidget();
 
     mwnd->show();
     app.exec();
