@@ -22,23 +22,27 @@
 
 namespace kt
 {
-
-PrefPageInterface::PrefPageInterface(KConfigSkeleton* cfg, const QString& name, const QString& icon, QWidget* parent)
-    : QWidget(parent), cfg(cfg), name(name), icon(icon)
-{}
-
+PrefPageInterface::PrefPageInterface(KConfigSkeleton *cfg, const QString &name, const QString &icon, QWidget *parent)
+    : QWidget(parent)
+    , cfg(cfg)
+    , name(name)
+    , icon(icon)
+{
+}
 
 PrefPageInterface::~PrefPageInterface()
-{}
+{
+}
 
 void PrefPageInterface::loadSettings()
-{}
+{
+}
 
 void PrefPageInterface::loadDefaults()
-{}
+{
+}
 
 void PrefPageInterface::updateSettings()
 {
 }
 }
-
