@@ -33,10 +33,10 @@
 
 #include "scanfolder.h"
 #include "scanfolderplugin.h"
-#include "scanfolderprefpage.h"
 #include "scanfolderpluginsettings.h"
-#include "torrentloadqueue.h"
+#include "scanfolderprefpage.h"
 #include "scanthread.h"
+#include "torrentloadqueue.h"
 
 using namespace bt;
 
@@ -44,15 +44,13 @@ K_PLUGIN_FACTORY_WITH_JSON(ktorrent_scanfolder, "ktorrent_scanfolder.json", regi
 
 namespace kt
 {
-
-ScanFolderPlugin::ScanFolderPlugin(QObject* parent, const QVariantList& args)
-    : Plugin(parent),
-      tlq(nullptr)
+ScanFolderPlugin::ScanFolderPlugin(QObject *parent, const QVariantList &args)
+    : Plugin(parent)
+    , tlq(nullptr)
 {
     Q_UNUSED(args);
 }
 
-
 ScanFolderPlugin::~ScanFolderPlugin()
 {
 }
@@ -62,7 +60,7 @@ void ScanFolderPlugin::load()
     LogSystemManager::instance().registerSystem(i18nc("plugin name", "Scan Folder"), SYS_SNF);
     tlq = new TorrentLoadQueue(getCore(), this);
     scanner = new ScanThread();
-    connect(scanner, &ScanThread::found, tlq, qOverload<const QList<QUrl>&>(&TorrentLoadQueue::add), Qt::QueuedConnection);
+    connect(scanner, &ScanThread::found, tlq, qOverload<const QList<QUrl> &>(&TorrentLoadQueue::add), Qt::QueuedConnection);
     pref = new ScanFolderPrefPage(this, nullptr);
     getGUI()->addPrefPage(pref);
     connect(getCore(), &CoreInterface::settingsChanged, this, &ScanFolderPlugin::updateScanFolders);
@@ -89,7 +87,7 @@ void ScanFolderPlugin::updateScanFolders()
     QStringList folders = ScanFolderPluginSettings::folders();
 
     // make sure folders end with /
-    for (QString& s : folders) {
+    for (QString &s : folders) {
         if (s.endsWith(bt::DirSeparator()))
             s += bt::DirSeparator();
     }
@@ -105,7 +103,7 @@ void ScanFolderPlugin::updateScanFolders()
     scanner->setFolderList(folders);
 }
 
-bool ScanFolderPlugin::versionCheck(const QString& version) const
+bool ScanFolderPlugin::versionCheck(const QString &version) const
 {
     return version == QStringLiteral(VERSION);
 }
