@@ -19,26 +19,29 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
+#include "scriptablegroup.h"
+#include <dbus/dbus.h>
+#include <interfaces/torrentinterface.h>
 #include <util/log.h>
 #include <util/sha1hash.h>
-#include <interfaces/torrentinterface.h>
-#include <dbus/dbus.h>
-#include "scriptablegroup.h"
 
 using namespace bt;
 
 namespace kt
 {
-
-ScriptableGroup::ScriptableGroup(const QString& name, const QString& icon, const QString& path, Kross::Object::Ptr script, DBus* api) : kt::Group(name, MIXED_GROUP, path), script(script), api(api)
+ScriptableGroup::ScriptableGroup(const QString &name, const QString &icon, const QString &path, Kross::Object::Ptr script, DBus *api)
+    : kt::Group(name, MIXED_GROUP, path)
+    , script(script)
+    , api(api)
 {
     setIconByName(icon);
 }
 
 ScriptableGroup::~ScriptableGroup()
-{}
+{
+}
 
-bool ScriptableGroup::isMember(bt::TorrentInterface* tor)
+bool ScriptableGroup::isMember(bt::TorrentInterface *tor)
 {
     QVariantList args;
     args << tor->getInfoHash().toString();
@@ -46,5 +49,4 @@ bool ScriptableGroup::isMember(bt::TorrentInterface* tor)
     return ret.toBool();
 }
 
-
 }
