@@ -28,34 +28,31 @@
 #include <KIO/CopyJob>
 #include <KLocalizedString>
 
-#include <util/log.h>
+#include "opensearchdownloadjob.h"
+#include "searchenginelist.h"
+#include <interfaces/functions.h>
 #include <util/error.h>
 #include <util/fileops.h>
-#include <interfaces/functions.h>
-#include "searchenginelist.h"
-#include "opensearchdownloadjob.h"
+#include <util/log.h>
 
 using namespace bt;
 
 namespace kt
 {
-
-SearchEngineList::SearchEngineList(ProxyHelper *proxy, const QString& data_dir) : m_proxy(proxy), data_dir(data_dir)
+SearchEngineList::SearchEngineList(ProxyHelper *proxy, const QString &data_dir)
+    : m_proxy(proxy)
+    , data_dir(data_dir)
 {
     // default_opensearch_urls << QUrl(QStringLiteral("https://torrentproject.com"));
-    default_urls << QUrl(QStringLiteral("http://btdig.com"))
-                 << QUrl(QStringLiteral("http://btdb.in"))
-                 << QUrl(QStringLiteral("https://torrentproject.se"))
+    default_urls << QUrl(QStringLiteral("http://btdig.com")) << QUrl(QStringLiteral("http://btdb.in")) << QUrl(QStringLiteral("https://torrentproject.se"))
                  << QUrl(QStringLiteral("http://duckduckgo.com"));
 }
 
-
 SearchEngineList::~SearchEngineList()
 {
     qDeleteAll(engines);
 }
 
-
 void SearchEngineList::loadEngines()
 {
     if (!bt::Exists(data_dir)) {
@@ -74,12 +71,11 @@ void SearchEngineList::loadEngines()
         }
     } else {
         QStringList subdirs = QDir(data_dir).entryList(QDir::Dirs | QDir::NoDotAndDotDot);
-        for (const QString& sd : qAsConst(subdirs)) {
-
+        for (const QString &sd : qAsConst(subdirs)) {
             // Load only if there is an opensearch.xml file and not a removed file
             if (bt::Exists(data_dir + sd + QStringLiteral("/opensearch.xml")) && !bt::Exists(data_dir + sd + QStringLiteral("/removed"))) {
                 Out(SYS_SRC | LOG_DEBUG) << "Loading " << sd << endl;
-                SearchEngine* se = new SearchEngine(data_dir + sd + QLatin1Char('/'));
+                SearchEngine *se = new SearchEngine(data_dir + sd + QLatin1Char('/'));
                 if (!se->load(data_dir + sd + QStringLiteral("/opensearch.xml")))
                     delete se;
                 else
@@ -105,7 +101,8 @@ void SearchEngineList::convertSearchEnginesFile()
     while (!in.atEnd()) {
         QString line = in.readLine();
 
-        if (line.startsWith(QLatin1Char('#')) || line.startsWith(QLatin1Char(' ')) || line.isEmpty()) continue;
+        if (line.startsWith(QLatin1Char('#')) || line.startsWith(QLatin1Char(' ')) || line.isEmpty())
+            continue;
 
         QStringList tokens = line.split(QLatin1Char(' '));
         QString name = tokens[0];
@@ -122,13 +119,13 @@ void SearchEngineList::convertSearchEnginesFile()
 
             bt::MakeDir(dir);
             addEngine(dir, url.toString().replace(QLatin1String("FOOBAR"), QLatin1String("{searchTerms}")));
-        } catch (bt::Error& err) {
+        } catch (bt::Error &err) {
             Out(SYS_SRC | LOG_NOTICE) << err.toString() << endl;
         }
     }
 }
 
-QUrl SearchEngineList::search(bt::Uint32 engine, const QString& terms)
+QUrl SearchEngineList::search(bt::Uint32 engine, const QString &terms)
 {
     QUrl u;
     if (engine < (Uint32)engines.count())
@@ -146,11 +143,11 @@ QString SearchEngineList::getEngineName(bt::Uint32 engine) const
         return engines[engine]->engineName();
 }
 
-void SearchEngineList::openSearchDownloadJobFinished(KJob* j)
+void SearchEngineList::openSearchDownloadJobFinished(KJob *j)
 {
-    OpenSearchDownloadJob* osdj = (OpenSearchDownloadJob*)j;
+    OpenSearchDownloadJob *osdj = (OpenSearchDownloadJob *)j;
     if (!osdj->error()) {
-        SearchEngine* se = new SearchEngine(osdj->directory());
+        SearchEngine *se = new SearchEngine(osdj->directory());
         if (!se->load(osdj->directory() + QStringLiteral("opensearch.xml"))) {
             delete se;
             bt::Delete(osdj->directory(), true);
@@ -163,12 +160,12 @@ void SearchEngineList::openSearchDownloadJobFinished(KJob* j)
     }
 }
 
-void SearchEngineList::addEngine(OpenSearchDownloadJob* j)
+void SearchEngineList::addEngine(OpenSearchDownloadJob *j)
 {
     openSearchDownloadJobFinished(j);
 }
 
-void SearchEngineList::addEngine(const QString& dir, const QString& url)
+void SearchEngineList::addEngine(const QString &dir, const QString &url)
 {
     QFile fptr(dir + QStringLiteral("opensearch.xml"));
     if (!fptr.open(QIODevice::WriteOnly))
@@ -176,12 +173,13 @@ void SearchEngineList::addEngine(const QString& dir, const QString& url)
 
     QUrl kurl(url);
     QTextStream out(&fptr);
-    QString xml_template = QStringLiteral("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
-                                          "<OpenSearchDescription xmlns=\"http://a9.com/-/spec/opensearch/1.1/\">\n"
-                                          "<ShortName>%1</ShortName>\n"
-                                          "<Url type=\"text/html\" template=\"%2\" />\n"
-                                          "<Image>%3/favicon.ico</Image>\n"
-                                          "</OpenSearchDescription>\n");
+    QString xml_template = QStringLiteral(
+        "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+        "<OpenSearchDescription xmlns=\"http://a9.com/-/spec/opensearch/1.1/\">\n"
+        "<ShortName>%1</ShortName>\n"
+        "<Url type=\"text/html\" template=\"%2\" />\n"
+        "<Image>%3/favicon.ico</Image>\n"
+        "</OpenSearchDescription>\n");
 
     QString base = kurl.scheme() + QStringLiteral("://") + kurl.host();
     if (kurl.port() > 0)
@@ -191,7 +189,7 @@ void SearchEngineList::addEngine(const QString& dir, const QString& url)
     tmp = tmp.replace(QLatin1Char('&'), QLatin1String("&amp;"));
     out << xml_template.arg(kurl.host()).arg(tmp).arg(base) << Qt::endl;
 
-    SearchEngine* se = new SearchEngine(dir);
+    SearchEngine *se = new SearchEngine(dir);
 
     if (!se->load(dir + QStringLiteral("opensearch.xml"))) {
         delete se;
@@ -202,16 +200,16 @@ void SearchEngineList::addEngine(const QString& dir, const QString& url)
     insertRow(engines.count() - 1);
 }
 
-void SearchEngineList::removeEngines(const QModelIndexList& sel)
+void SearchEngineList::removeEngines(const QModelIndexList &sel)
 {
-    QList<SearchEngine*> to_remove;
-    for (const QModelIndex& idx : sel) {
+    QList<SearchEngine *> to_remove;
+    for (const QModelIndex &idx : sel) {
         if (idx.isValid() && idx.row() >= 0 && idx.row() < engines.count())
             to_remove.append(engines.at(idx.row()));
     }
 
     beginResetModel();
-    for (SearchEngine* se : qAsConst(to_remove)) {
+    for (SearchEngine *se : qAsConst(to_remove)) {
         bt::Touch(se->engineDir() + QStringLiteral("removed"));
         engines.removeAll(se);
         delete se;
@@ -242,7 +240,7 @@ void SearchEngineList::addDefaults()
         Out(SYS_SRC | LOG_DEBUG) << "Setting up default engine " << u.toDisplayString() << endl;
         QString dir = data_dir + u.host() + QLatin1Char('/');
         if (!bt::Exists(dir)) {
-            OpenSearchDownloadJob* j = new OpenSearchDownloadJob(u, dir, m_proxy);
+            OpenSearchDownloadJob *j = new OpenSearchDownloadJob(u, dir, m_proxy);
             connect(j, &OpenSearchDownloadJob::result, this, &SearchEngineList::openSearchDownloadJobFinished);
             j->start();
         } else {
@@ -255,7 +253,7 @@ void SearchEngineList::addDefaults()
     endResetModel();
 }
 
-void SearchEngineList::loadEngine(const QString& global_dir, const QString& user_dir, bool load_removed)
+void SearchEngineList::loadEngine(const QString &global_dir, const QString &user_dir, bool load_removed)
 {
     if (!bt::Exists(user_dir)) {
         // create directory to store icons
@@ -271,7 +269,7 @@ void SearchEngineList::loadEngine(const QString& global_dir, const QString& user
     }
 
     if (!alreadyLoaded(user_dir)) {
-        SearchEngine* se = new SearchEngine(user_dir);
+        SearchEngine *se = new SearchEngine(user_dir);
         if (!se->load(global_dir + QStringLiteral("opensearch.xml")))
             delete se;
         else
@@ -279,26 +277,26 @@ void SearchEngineList::loadEngine(const QString& global_dir, const QString& user
     }
 }
 
-
 void SearchEngineList::loadDefault(bool removed_to)
 {
-    QStringList dir_list = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("ktorrent/opensearch"), QStandardPaths::LocateDirectory);
+    QStringList dir_list =
+        QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("ktorrent/opensearch"), QStandardPaths::LocateDirectory);
     if (dir_list.isEmpty())
         dir_list = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("ktorrent/opensearch"), QStandardPaths::LocateDirectory);
     if (dir_list.isEmpty())
         dir_list = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("ktorrent/opensearch"), QStandardPaths::LocateDirectory);
 
-    for (const QString& dir : qAsConst(dir_list)) {
+    for (const QString &dir : qAsConst(dir_list)) {
         const QStringList subdirs = QDir(dir).entryList(QDir::Dirs | QDir::NoDotAndDotDot);
-        for (const QString& sd : subdirs) {
+        for (const QString &sd : subdirs) {
             loadEngine(QDir::cleanPath(dir) + QLatin1Char('/') + sd + QLatin1Char('/'), data_dir + sd + QLatin1Char('/'), removed_to);
         }
     }
 }
 
-bool SearchEngineList::alreadyLoaded(const QString& user_dir)
+bool SearchEngineList::alreadyLoaded(const QString &user_dir)
 {
-    for (const SearchEngine* se : qAsConst(engines)) {
+    for (const SearchEngine *se : qAsConst(engines)) {
         if (se->engineDir() == user_dir)
             return true;
     }
@@ -306,7 +304,7 @@ bool SearchEngineList::alreadyLoaded(const QString& user_dir)
     return false;
 }
 
-int SearchEngineList::rowCount(const QModelIndex& parent) const
+int SearchEngineList::rowCount(const QModelIndex &parent) const
 {
     if (!parent.isValid())
         return engines.count();
@@ -314,12 +312,12 @@ int SearchEngineList::rowCount(const QModelIndex& parent) const
         return 0;
 }
 
-QVariant SearchEngineList::data(const QModelIndex& index, int role) const
+QVariant SearchEngineList::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid())
         return QVariant();
 
-    SearchEngine* se = engines.at(index.row());
+    SearchEngine *se = engines.at(index.row());
     if (!se)
         return QVariant();
 
@@ -334,7 +332,7 @@ QVariant SearchEngineList::data(const QModelIndex& index, int role) const
     return QVariant();
 }
 
-bool SearchEngineList::insertRows(int row, int count, const QModelIndex& parent)
+bool SearchEngineList::insertRows(int row, int count, const QModelIndex &parent)
 {
     Q_UNUSED(parent);
     beginInsertRows(QModelIndex(), row, row + count - 1);
@@ -342,12 +340,12 @@ bool SearchEngineList::insertRows(int row, int count, const QModelIndex& parent)
     return true;
 }
 
-bool SearchEngineList::removeRows(int row, int count, const QModelIndex& parent)
+bool SearchEngineList::removeRows(int row, int count, const QModelIndex &parent)
 {
     Q_UNUSED(parent);
     beginRemoveRows(QModelIndex(), row, row + count - 1);
     for (int i = 0; i < count; i++) {
-        SearchEngine* se = engines.takeAt(row);
+        SearchEngine *se = engines.takeAt(row);
         bt::Touch(se->engineDir() + QLatin1String("removed"));
         delete se;
     }
